@@ -96,6 +96,7 @@ def setup(**settings_patches):
     local('mkdir -p /var/run/beanstalk')
     local('cp %s /etc/init.d/beanstalk' % os.path.join(BEANSTALK_ROOT_PATH, 'static/beanstalk_init.sh'))
     local('chmod +x /etc/init.d/beanstalk')
+    local('chkconfig beanstalk on')
 
     # Do you have user "beanstalk"?
     with settings(hide('everything'), warn_only=True):
@@ -130,6 +131,7 @@ def setup(**settings_patches):
     # Global ini
     local('mkdir -p /etc/beanstalk')
     if not os.path.exists('/etc/beanstalk/uwsgi.ini'):
+        print section_title('Create global settings')
         global_uwsgi_ini_template_path = os.path.join(BEANSTALK_ROOT_PATH, 'static/global_uwsgi.ini')
         with hide('everything'):
             uid = local('id -u beanstalk', capture=True)
@@ -138,17 +140,17 @@ def setup(**settings_patches):
             f.write(global_uwsgi_ini_content)
 
     # Apache command
-    print section_title('Create apache-reload command')
     httpd_cmd_path = '/usr/sbin/httpd_reload'
     if not os.path.exists(httpd_cmd_path):
+        print section_title('Create apache-reload command')
         httpd_cmd_source = os.path.join(BEANSTALK_ROOT_PATH, 'static/httpd_reload.sh')
         local('/bin/cp -f %s %s' % (httpd_cmd_source, httpd_cmd_path))
         local('chmod +x %s' % httpd_cmd_path)
 
     # Give beanstalk permission
-    print section_title('Give beanstalk permission for apache-reload command')
     sudoer_file = '/etc/sudoers.d/beanstalk_reload_httpd'
     if not os.path.exists(sudoer_file):
+        print section_title('Give beanstalk permission for apache-reload command')
         local('echo "beanstalk ALL=(root) NOPASSWD: %s" > %s' % (httpd_cmd_path, sudoer_file))
         local('chmod 440 %s' % sudoer_file)
 
@@ -175,11 +177,12 @@ def setup(**settings_patches):
     if not os.path.exists('/etc/httpd/conf.d/beanstalk_app.conf'):
         local('ln -s %s /etc/httpd/conf.d/beanstalk_app.conf' % apache_conf_path())
 
+    print section_title('Final setup')
     local('chown -R beanstalk:beanstalk %s' % beanstalk_stack_base)
-    local('/etc/init.d/sshd restart')
-    local('/etc/init.d/httpd restart')
-    local('/etc/init.d/beanstalk start')
-    local('chkconfig beanstalk on')
+    with settings(hide('warnings'), warn_only=True):
+        local('/etc/init.d/beanstalk restart')
+        local('/etc/init.d/sshd restart')
+        local('/etc/init.d/httpd restart')
 
     # Call post-setup script
     run_hooked_actions('POST_SETUP_ACTIONS')
